
/**************************************************************************
 *
 *  $Id: prectime.c 1.1 2012/05/23 13:35:59Z martin REL_M $
 *
 *  Copyright (c) Meinberg Funkuhren, Bad Pyrmont, Germany
 *
 *  Description:
 *    Dynamic support for precision filetime API calls
 *    introduced with Windows 8.
 *
 * -----------------------------------------------------------------------
 *  $Log: prectime.c $
 *  Revision 1.1  2012/05/23 13:35:59Z  martin
 *  Initial revision.
 *
 **************************************************************************/

#define _PRECTIME
 #include <prectime.h>
#undef _PRECTIME



/*HDR*/
/**
 * @brief Try to import an API function to read precise Windows system time
 *
 * Check if the Windows API call GetSystemTimeAsPreciseFileTime() is
 * available. This function has been introduced with Windows 8, so it is
 * not available on older Windows versions, and thus the API call is
 * imported from kernel32.dll at runtime.
 *
 * @param fnc  address of a function pointer which is set to the imported
 *             API function, or to NULL if the API call is not supported
 *
 * @return ERROR_SUCCESS on success, else code returned by GetLastError()
 *
 * @see GetSystemTimeAsPreciseFileTime()
 */
DWORD import_precise_time_api( GSTAFT_FNC *fnc )
{
  GSTAFT_FNC tmp_fnc = NULL;
  HINSTANCE h = LoadLibrary( "kernel32.dll" );

  if ( h == NULL )
    goto fail;

  tmp_fnc = (GSTAFT_FNC) GetProcAddress( h, "GetSystemTimePreciseAsFileTime" );

  if ( tmp_fnc == NULL )
    goto fail;

  if ( fnc )
    *fnc = tmp_fnc;

  return ERROR_SUCCESS;


fail:
  if ( fnc )
    *fnc = NULL;

  return GetLastError();

}  // import_precise_time_api


