
/**************************************************************************
 *
 *  $Id: prectime.h 1.1 2012/05/23 13:35:59Z martin REL_M $
 *
 *  Copyright (c) Meinberg Funkuhren, Bad Pyrmont, Germany
 *
 *  Description:
 *    Definitions and prototypes for prectime.c.
 *
 * -----------------------------------------------------------------------
 *  $Log: prectime.h $
 *  Revision 1.1  2012/05/23 13:35:59Z  martin
 *  Initial revision.
 *
 **************************************************************************/

#ifndef _PRECTIME_H
#define _PRECTIME_H


/* Other headers to be included */

#include <windows.h>

#ifdef _PRECTIME
 #define _ext
 #define _DO_INIT
#else
 #define _ext extern
#endif


/* Start of header body */

#ifdef __cplusplus
extern "C" {
#endif


/**
 * @brief Get precise Windows system time as FILETIME.
 *
 * @note This function has been introduced with Windows 8,
 * so it is not available on older Windows versions. Thus
 * the API call is imported from kernel32.dll at runtime.
 *
 * @param lpSystemTimeAsFileTime pointer to a FILETIME to be filled
 *
 * @see GSTAFT_FNC
 * @see import_precise_time_api()
 */
WINBASEAPI
VOID
WINAPI
GetSystemTimeAsPreciseFileTime(
    LPFILETIME lpSystemTimeAsFileTime
    );


/**
 * @brief A pointer to a function returning the system time as FILETIME
 *
 * This can be e.g. the standard Windows API call GetSystemTimeAsFileTime() 
 * or the GetSystemTimeAsPreciseFileTime() API call introduced with Windows 8.
 */
typedef VOID (WINAPI *GSTAFT_FNC)(LPFILETIME lpSystemTimeAsFileTime);




/* function prototypes: */

/* ----- function prototypes begin ----- */

/* This section was generated automatically */
/* by MAKEHDR, do not remove the comments. */

 /**
 * @brief Try to import an API function to read precise Windows system time
 *
 * Check if the Windows API call GetSystemTimeAsPreciseFileTime() is
 * available. This function has been introduced with Windows 8, so it is
 * not available on older Windows versions, and thus the API call is
 * imported from kernel32.dll at runtime.
 *
 * @param fnc  address of a function pointer which is set to the imported
 *             API function, or to NULL if the API call is not supported
 *
 * @return ERROR_SUCCESS on success, else code returned by GetLastError()
 *
 * @see GetSystemTimeAsPreciseFileTime()
 */
 DWORD import_precise_time_api( GSTAFT_FNC *fnc ) ;


/* ----- function prototypes end ----- */

#ifdef __cplusplus
}
#endif


/* End of header body */

#undef _ext
#undef _DO_INIT

#endif  /* _PRECTIME_H */
